pywr.recorders.StorageRecorder
==============================

.. currentmodule:: pywr.recorders

.. autoclass:: StorageRecorder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StorageRecorder.after
      ~StorageRecorder.aggregated_value
      ~StorageRecorder.before
      ~StorageRecorder.finish
      ~StorageRecorder.load
      ~StorageRecorder.register
      ~StorageRecorder.reset
      ~StorageRecorder.setup
      ~StorageRecorder.unregister
      ~StorageRecorder.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~StorageRecorder.agg_func
      ~StorageRecorder.children
      ~StorageRecorder.comment
      ~StorageRecorder.epsilon
      ~StorageRecorder.ignore_nan
      ~StorageRecorder.is_constraint
      ~StorageRecorder.is_objective
      ~StorageRecorder.model
      ~StorageRecorder.name
      ~StorageRecorder.node
      ~StorageRecorder.parents
   
   